@@ -52,6 +52,7 @@ enum libvlc_event_e {
     libvlc_MediaParsedChanged,
     libvlc_MediaFreed,
     libvlc_MediaStateChanged,
+    libvlc_MediaSubItemTreeAdded,
 
     libvlc_MediaPlayerMediaChanged=0x100,
     libvlc_MediaPlayerNothingSpecial,
@@ -72,6 +73,12 @@ enum libvlc_event_e {
     libvlc_MediaPlayerSnapshotTaken,
     libvlc_MediaPlayerLengthChanged,
     libvlc_MediaPlayerVout,
+    libvlc_MediaPlayerScrambledChanged,
+    libvlc_MediaPlayerCorked = libvlc_MediaPlayerScrambledChanged + 3 + 1,
+    libvlc_MediaPlayerUncorked,
+    libvlc_MediaPlayerMuted,
+    libvlc_MediaPlayerUnmuted,
+    libvlc_MediaPlayerAudioVolume,
 
     libvlc_MediaListItemAdded=0x200,
     libvlc_MediaListWillAddItem,
@@ -137,6 +144,10 @@ typedef struct libvlc_event_t
         {
             libvlc_state_t new_state;
         } media_state_changed;
+        struct
+        {
+            libvlc_media_t * item;
+        } media_subitemtree_added;
 
         /* media instance */
         struct
@@ -164,6 +175,10 @@ typedef struct libvlc_event_t
             int new_pausable;
         } media_player_pausable_changed;
         struct
+        {
+            int new_scrambled;
+        } media_player_scrambled_changed;
+        struct
         {
             int new_count;
         } media_player_vout;
@@ -220,6 +235,11 @@ typedef struct libvlc_event_t
         {
             libvlc_media_t * new_media;
         } media_player_media_changed;
+
+        struct
+        {
+            float volume;
+        } media_player_audio_volume;
     } u; /**< Type-dependent event description */
 } libvlc_event_t;
 
