@@ -2,7 +2,7 @@
  * g711.c: G.711 µ-law and A-law codec
  *****************************************************************************
  * Copyright (C) 2001, 2003 VLC authors and VideoLAN
- * $Id: 0473c73017a9677f91c4e02cf80959bbcebae042 $
+ * $Id: 5d89471e3ed3aaaa1aa8fe584e0863b4b1a52967 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -244,9 +244,6 @@ static block_t *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
         return NULL;
     }
 
-    /* Create chunks of max 1024 samples */
-    if( samples > 1024 ) samples = 1024;
-
     block_t *p_out = decoder_NewAudioBuffer( p_dec, samples );
     if( p_out == NULL )
     {
@@ -269,9 +266,7 @@ static block_t *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
     for( unsigned i = 0; i < samples; i++ )
        *(dst++) = p_sys->table[*(src++)];
 
-    p_block->p_buffer += samples;
-    p_block->i_buffer -= samples;
-
+    block_Release( p_block );
     return p_out;
 }
 
