@@ -2,7 +2,7 @@
  * xspf.c : XSPF playlist import functions
  *******************************************************************************
  * Copyright (C) 2006-2011 VLC authors and VideoLAN
- * $Id: db7cc7f09f8f833dadff96b781aeb85dbb300685 $
+ * $Id: a8083477f1178e83fe782fbe4947b2bcf94bc4a6 $
  *
  * Authors: Daniel Stränger <vlc at schmaller dot de>
  *          Yoann Peronneau <yoann@videolan.org>
@@ -84,8 +84,9 @@ static int Demux(demux_t *);
  */
 int Import_xspf(vlc_object_t *p_this)
 {
-    DEMUX_BY_EXTENSION_OR_FORCED_MSG(".xspf", "xspf-open",
+    DEMUX_BY_EXTENSION_OR_MIMETYPE(".xspf", "application/xspf+xml",
                                       "using XSPF playlist reader");
+
     return VLC_SUCCESS;
 }
 
@@ -113,7 +114,7 @@ static int Demux(demux_t *p_demux)
     p_demux->p_sys->pp_tracklist = NULL;
     p_demux->p_sys->i_tracklist_entries = 0;
     p_demux->p_sys->i_track_id = -1;
-    p_demux->p_sys->psz_base = NULL;
+    p_demux->p_sys->psz_base = FindPrefix(p_demux);
 
     /* create new xml parser from stream */
     p_xml_reader = xml_ReaderCreate(p_demux, p_demux->s);
@@ -428,7 +429,7 @@ static bool parse_track_node COMPLEX_INTERFACE
                 free(psz_uri);
 
             if (p_sys->i_track_id < 0
-             || (unsigned)p_sys->i_track_id >= (SIZE_MAX / sizeof(p_new_input)))
+             || (size_t)p_sys->i_track_id >= (SIZE_MAX / sizeof(p_new_input)))
             {
                 input_item_node_AppendNode(p_input_node, p_new_node);
                 vlc_gc_decref(p_new_input);
@@ -479,8 +480,6 @@ static bool parse_track_node COMPLEX_INTERFACE
              * and anchors (#...) are not resolved correctly. Also,
              * host-relative (/...) and directory-relative locations
              * ("relative path" in vernacular) should be resolved.
-             * Last, psz_base should default to the XSPF resource
-             * location if missing (not the current working directory).
              * -- Courmisch */
             if (p_sys->psz_base && !strstr(psz_value, "://"))
             {
