@@ -2,7 +2,7 @@
  * aout_internal.h : internal defines for audio output
  *****************************************************************************
  * Copyright (C) 2002 VLC authors and VideoLAN
- * $Id: abe65132caf58961cd0814f59f9b33a3956c545f $
+ * $Id: 10c790b383b8b1989aa71c0c7500230bb2882e51 $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -136,8 +136,6 @@ bool aout_ChangeFilterString( vlc_object_t *manager, vlc_object_t *aout,
 int aout_DecNew(audio_output_t *, const audio_sample_format_t *,
                 const audio_replay_gain_t *, const aout_request_vout_t *);
 void aout_DecDelete(audio_output_t *);
-block_t *aout_DecNewBuffer(audio_output_t *, size_t);
-void aout_DecDeleteBuffer(audio_output_t *, block_t *);
 int aout_DecPlay(audio_output_t *, block_t *, int i_input_rate);
 int aout_DecGetResetLost(audio_output_t *);
 void aout_DecChangePause(audio_output_t *, bool b_paused, mtime_t i_date);
